@@ -188,9 +188,23 @@ def delete_model_version(external_id, confirm=True):
             the function `get_model_version_overview`
         - confirm: (bool) whether the user will be asked to confirm deletion
     """
-    model, environment, version = external_id.split("/")
+    try:
+        model, environment, version = external_id.split("/")
+    except ValueError:
+        logging.error(f"Expected external id format: 'name/env/version'")
+        return
+
     confirmed = False
 
+    file_list = cdf.query_file_versions(
+        directory_prefix='/mlops', 
+        external_id_prefix=external_id,
+        uploaded=None
+    )
+    if file_list.empty:
+        logging.error(f"File with '{external_id=}' not found")
+        return
+
     if confirm:
         def confirm_prompt(question):
             reply = None
